# 🧠 datainstinct

**datainstinct** is a lightweight Python library for quick data profiling and summary of CSV or Excel or JSON files.

---

##  Installation

```bash
pip install dhanuma_datainstinct
